==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-link.h <==
/*
 * $Id: st-link.h,v 1.4 2004/01/05 19:44:10 jylefort Exp $
 *
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_LINK_H
#define _ST_LINK_H

#include <gtk/gtk.h>

#define ST_TYPE_LINK		(st_link_get_type())
#define ST_LINK(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_LINK, STLink))
#define ST_LINK_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_LINK, STLinkClass))
#define ST_IS_LINK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_LINK))
#define ST_IS_LINK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_LINK))
#define ST_LINK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_LINK, STLinkClass))

typedef struct
{
  GtkEventBox		event_box;

  GtkWidget		*label;
  GtkItemFactory	*factory;

  char			*text;
  char			*uri;
  gboolean		in_link;
} STLink;

typedef struct
{
  GtkEventBoxClass	parent_class;
} STLinkClass;

GType		st_link_get_type	(void);
GtkWidget	*st_link_new		(void);
void		st_link_set_text	(STLink		*link,
					 const char	*text);
void		st_link_set_uri		(STLink		*link,
					 const char	*uri);

#endif /* _ST_LINK_H */

==> streamtuner-0.12.2.tar.gz: streamtuner-0.12.2/src/streamtuner/st-link.h <==
/*
 * $Id: st-link.h,v 1.5 2004/03/08 06:30:06 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_LINK_H
#define _ST_LINK_H

#include <gtk/gtk.h>

#define ST_TYPE_LINK		(st_link_get_type())
#define ST_LINK(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_LINK, STLink))
#define ST_LINK_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_LINK, STLinkClass))
#define ST_IS_LINK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_LINK))
#define ST_IS_LINK_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_LINK))
#define ST_LINK_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_LINK, STLinkClass))

typedef struct _STLinkPrivate STLinkPrivate;

typedef struct
{
  GtkEventBox		event_box;

  STLinkPrivate		*priv;
} STLink;

typedef struct
{
  GtkEventBoxClass	parent_class;
} STLinkClass;

GType		st_link_get_type	(void);
GtkWidget	*st_link_new		(void);
void		st_link_set_text	(STLink		*link,
					 const char	*text);
void		st_link_set_uri		(STLink		*link,
					 const char	*uri);

#endif /* _ST_LINK_H */
